@@ -8,7 +8,6 @@ from opaque_keys.edx.keys import CourseKey
 #   and used in the unit tests. Using 'disable=reimported' with pylint will work,
 #   because we just use the cached signal list.
 from openedx_events.content_authoring import signals  # pylint: disable=unused-import
-from openedx_events.enterprise import signals  # pylint: disable=reimported
 from openedx_events.event_bus.avro.deserializer import AvroSignalDeserializer
 from openedx_events.event_bus.avro.serializer import AvroSignalSerializer
 from openedx_events.event_bus.avro.tests.test_utilities import (
@@ -34,7 +33,7 @@ def generate_test_event_data_for_data_type(data_type):
     """
     Generates test data for use in the event bus test cases.
 
-    Builds data by filling in dummy data for basic data types (int/bool/str)
+    Builds data by filling in dummy data for basic data types (int/float/bool/str)
     and recursively breaks down the classes for nested classes into basic data types.
 
     Arguments:
@@ -48,6 +47,7 @@ def generate_test_event_data_for_data_type(data_type):
         int: 1,
         bool: True,
         str: "default",
+        float: 1.0,
         CourseKey: CourseKey.from_string("course-v1:edX+DemoX.1+2014"),
         datetime: datetime.now(),
     }
